<?php
/**
* Plugin Name: FSM Backend Category Organizer
* Description: Allows you to group and sort the categories and other taxonomy items on the WordPress backend, showing them more efficiently in the posts editing page.
* Version: 1.15
* Author: Fesomia
* Author URI: https://wp.fesomia.cat

 * Text Domain: fsm-backend-category-organizer
 * Domain Path: /languages
*/


// Prevent direct access
if (!defined('ABSPATH')) {
    die('You cannot access this resource directly.');
}

//custom walker
class FSMBCO_Walker_Category_Checklist extends Walker {
	public $tree_type = 'category';
	public $db_fields = array ('parent' => 'parent', 'id' => 'term_id'); 

	//Start the list before adding the elements
	public function start_lvl( &$output, $depth = 0, $args = array() ) {
		$indent = str_repeat("\t", $depth);
		$output .= "$indent<ul class='children'>\n";
	}

	//End the list
	public function end_lvl( &$output, $depth = 0, $args = array() ) {
		$indent = str_repeat("\t", $depth);
		$output .= "$indent</ul>\n";
	}

	/**
	 * Start the element output.
	 * @param string $output   Passed by reference. Used to append additional content.
	 * @param object $category The current term object.
	 * @param int    $depth    Depth of the term in reference to parents. Default 0.
	 * @param array  $args     An array of arguments. @see wp_terms_checklist()
	 * @param int    $id       ID of the current term.
	 */
	public function start_el( &$output, $category, $depth = 0, $args = array(), $id = 0 ) {
		if ( empty( $args['taxonomy'] ) ) {
			$taxonomy = 'category';
		} else {
			$taxonomy = $args['taxonomy'];
		}

		if ( $taxonomy == 'category' ) {
			$name = 'post_category';
		} else {
			$name = 'tax_input[' . $taxonomy . ']';
		}

		$name_field="";
		if (empty($args['xtest'])) {
			$name_field = 'name="'.$name.'[]"';
		}

		$args['popular_cats'] = empty( $args['popular_cats'] ) ? array() : $args['popular_cats'];
		$class = in_array( $category->term_id, $args['popular_cats'] ) ? ' class="popular-category"' : '';

		$args['selected_cats'] = empty( $args['selected_cats'] ) ? array() : $args['selected_cats'];



		$output .= "\n<li id='{$taxonomy}-{$category->term_id}'$class>" .
			'<label class="selectit"><input value="' . $category->term_id . '" type="checkbox" '.$name_field.' id="in-tax-' . $category->term_id . '"' .
			checked( in_array( $category->term_id, $args['selected_cats'] ), true, false ) .
			disabled( empty( $args['disabled'] ), false, false ) . 'data-nom="'.$category->name.'"'.' data-arbre="'.FSMBCO_category_parents_tree($taxonomy, $category->term_id,false,' / ').'"/> ' .
			esc_html( apply_filters( 'the_category', $category->name ) ) . '</label>';

	}

	/**
	 * Ends the element output, if needed.
	 * @param string $output   Passed by reference. Used to append additional content.
	 * @param object $category The current term object.
	 * @param int    $depth    Depth of the term in reference to parents. Default 0.
	 * @param array  $args     An array of arguments. @see wp_terms_checklist()
	 
	 */
	public function end_el( &$output, $category, $depth = 0, $args = array() ) {
		$output .= "</li>\n";
	}
}

//Generates the chain of relatives of an element
function FSMBCO_category_parents_tree( $taxonomy, $id, $link = false, $separator = '/', $nicename = false, $visited = array() ) {
	$chain = '';
	$parent = get_term( $id, $taxonomy );
	if ( is_wp_error( $parent ) ) {	return $parent;}

	if ( $nicename ) {
		$name = $parent->slug;
	} else {
		$name = $parent->name;
	}

	if ( $parent->parent && ( $parent->parent != $parent->term_id ) && !in_array( $parent->parent, $visited ) ) {
		$visited[] = $parent->parent;
		$chain .= FSMBCO_category_parents_tree( $taxonomy, $parent->parent, $link, $separator, $nicename, $visited ).$separator;
	}

	$chain .= $name;

	return $chain;
}




//Generates the checklist of the children of the category that we passed
function FSMBCO_terms_checklist( $post_id = 0, $args = array() ) {
 	$defaults = array(
		'descendants_and_self' => 0,
		'selected_cats' => false,
		'popular_cats' => false,
		'walker' => null,
		'taxonomy' => 'category',
		'checked_ontop' => false,
		'echo' => true,
		'exclude' => array()
	);

	$params = apply_filters( 'wp_terms_checklist_args', $args, $post_id );

	$r = wp_parse_args( $params, $defaults );

	if ( empty( $r['walker'] ) || ! ( $r['walker'] instanceof Walker ) ) {
		$walker = new FSMBCO_Walker_Category_Checklist;
	} else {
		$walker = $r['walker'];
	}

	$taxonomy = $r['taxonomy'];
	$descendants_and_self = (int) $r['descendants_and_self'];

	$args = array( 'taxonomy' => $taxonomy );

	$tax = get_taxonomy( $taxonomy );
	$args['disabled'] = ! current_user_can( $tax->cap->assign_terms );

	$args['list_only'] = ! empty( $r['list_only'] );

	$args['xtest'] = isset($params['xtest'])?$params['xtest']:'';

	if ( is_array( $r['selected_cats'] ) ) {
		$args['selected_cats'] = $r['selected_cats'];
	} elseif ( $post_id ) {
		$args['selected_cats'] = wp_get_object_terms( $post_id, $taxonomy, array_merge( $args, array( 'fields' => 'ids' ) ) );
	} else {
		$args['selected_cats'] = array();
	}
	if ( is_array( $r['popular_cats'] ) ) {
		$args['popular_cats'] = $r['popular_cats'];
	} else {
		$args['popular_cats'] = get_terms( $taxonomy, array(
			'fields' => 'ids',
			'orderby' => 'count',
			'order' => 'DESC',
			'number' => 10,
			'hierarchical' => false
		) );
	}
	if ( $descendants_and_self ) {
		$categories = (array) get_terms( $taxonomy, array(
			'child_of' => $descendants_and_self,
			'hierarchical' => 0,
			'hide_empty' => 0,
			'exclude'=>$r['exclude']
		) );
		$self = get_term( $descendants_and_self, $taxonomy );
		array_unshift( $categories, $self );
	} else {
		$categories = (array) get_terms( $taxonomy, array( 'get' => 'all' ) );
	}

	$output = '';


	$output .= call_user_func_array( array( $walker, 'walk' ), array( $categories, 0, $args ) );

	if ( $r['echo'] ) {
		echo $output;
	}

	return $output;
}


//Show the selected items in a list
function FSMBCO_selected_terms_checklist( $taxonomy, $checklist = true, $echo = true ) {
	$post = get_post();

	if ( $post && $post->ID ) {
		$checked_terms = wp_get_object_terms($post->ID, $taxonomy, array('fields' => 'ids'));
	} else {
		$checked_terms = array();
	}


	$terms = get_the_terms( $post->ID, $taxonomy );


	$tax = get_taxonomy($taxonomy);

	$selected_ids = array();
	$ccat = array();
	foreach ( (array) $terms as $term ) {
		if (!$term) { continue; }

		$selected_ids[] = $term->term_id;
		if ( !$echo ) { continue; }
		$id = "popular-$taxonomy-$term->term_id";
		$checked = in_array( $term->term_id, $checked_terms ) ? 'checked="checked"' : '';

		if ($checklist) {
		?>

		<li id="<?php echo $id; ?>" class="popular-category">
			<label class="selectit">
				<input id="in-<?php echo $id; ?>" type="checkbox" <?php echo $checked; ?> value="<?php echo (int) $term->term_id; ?>" <?php disabled( ! current_user_can( $tax->cap->assign_terms ) ); ?> />
				<?php

				echo FSMBCO_category_parents_tree( $taxonomy, $term->term_id, false, ' / ' );

				?>
			</label>
		</li>

		<?php

		} else {
			$ccat[$term->term_id] = FSMBCO_category_parents_tree( $taxonomy, $term->term_id, false, ' / ' );

		}

	}
	if (!empty($ccat)) {
		asort($ccat);
		foreach ($ccat as $cat_id => $cat_nom) { 
			if (!empty($cat_id)) {
		?>
			<span><a href="#" data-category="<?php echo $cat_id;?>">X</a><?php echo $cat_nom; ?></span>
		<?php
			}
		}

	}

	return $selected_ids;
}






/**
 * Generated by the WordPress Option Page generator
 * at http://jeremyhixon.com/wp-tools/option-page/
 */

class FSMBCO_CategoryOrganizer {
	private $backend_category_organizer_options;
	
	public $taxonomy;

	public function __construct($taxonomy) {
		
		if (empty($taxonomy)) { $taxonomy = "category"; }
		
		$this->taxonomy = $taxonomy;


		
		$this->backend_category_organizer_options = get_option( 'backend_category_organizer_config' );
		add_action( 'admin_menu', array( $this, 'backend_category_organizer_add_plugin_page' ) );
		add_action( 'admin_init', array( $this, 'backend_category_organizer_page_init' ) );
		add_action( 'init', array( $this, 'FSMBCO_load_textdomain' ) );
		
		//Activate the hook only if it is active (for any taxonomy)		
		if (isset($this->backend_category_organizer_options['activar_plugin'])) {
			add_action( 'edit_form_after_editor', array( $this, 'FSMBCO_post_tags_meta_box_remove' ) );
			add_action( 'edit_form_after_editor', array( $this, 'FSMBCO_add_new_tags_metabox' ) );
		}
		
		add_action('admin_enqueue_scripts', array( $this, 'FSMBCO_enqueue' ) );
		
	}
	
	//enqueue css and scripts
	public function FSMBCO_enqueue($hook) {

		wp_enqueue_script( 'FSMBCO_functions', plugin_dir_url(__FILE__) . 'js/FSMBCO_edit_page.js', array('jquery'),'1.15' );
		wp_enqueue_script( 'FSMBCO_scrolltabs', plugin_dir_url(__FILE__) . 'js/jquery.scrolltabs.js', array('jquery'),'1.15' );
		
		wp_enqueue_style( 'FSMBCO_admin_css', plugin_dir_url(__FILE__) . 'css/admin.css', false, '1.15.0' );
		wp_enqueue_style( 'FSMBCO_scrolltabs_css', plugin_dir_url(__FILE__) . 'css/scrolltabs.css', false, '1.15.0' );
	}
	

	// Load plugin textdomain.
	function FSMBCO_load_textdomain() {
	  load_plugin_textdomain( 'fsm-backend-category-organizer', false, dirname( plugin_basename( __FILE__ ) ) . '/languages' ); 
	}
	
	// get hierarchical taxonomies of the current post 
	public function FSMBCO_get_post_taxonomies() {
		$taxonomies = array();
		$taxos = get_post_taxonomies();

		foreach ($taxos as $taxoname)
		{
			$taxoinfo = get_taxonomy( $taxoname );
			if ( $taxoinfo->hierarchical ) { $taxonomies[] = $taxoname; }
		}
		return $taxonomies;


	}	
	
	//Remove default category box
	public function FSMBCO_post_tags_meta_box_remove() {

		$taxos = get_post_taxonomies();
		//$post_type = 'post';
		$post_type = get_post_type();
		$position = 'side';
		foreach ($taxos as $taxoname)
		{	//----- afegir check per veure si estan activades o no
			if (isset($this->backend_category_organizer_options['activar_plugin'][$taxoname]))
			{
				$id = $taxoname.'div';
				remove_meta_box( $id, $post_type, $position );
			}
		}
	}
	
	//New categories box
	public function FSMBCO_add_new_tags_metabox(){
		$id = 'FSMBCO-post_tag'; // it should be unique
		$callback = 'FSMBCO_metabox_content'; // the name of the callback function
		$post_type = get_post_type();
		$position = 'side';
		$pri = 'default'; // priority, 'default' is good for us

		$taxos = $this->FSMBCO_get_post_taxonomies();
		//var_dump($taxos,get_post_taxonomies());
		foreach ($taxos as $taxo)
		{	
			if (isset($this->backend_category_organizer_options['activar_plugin'][$taxo]))
			{
				$taxonomy_info = get_taxonomy ( $taxo );
				$heading = $taxonomy_info->labels->name;
				$id = 'FSMBCO-'.$taxo.'_tag';
				add_meta_box( $id, $heading, array( $this, $callback), $post_type, $position, $pri, $taxo);
			}
		}

	}
	
	//Remove default category box
	public function extra_FSMBCO_post_tags_meta_box_remove() {		
		$id = 'actorsdiv';
		$post_type = 'post';
		$position = 'side';
		remove_meta_box( $id, $post_type, $position );
	}
	
	//New categories box
	public function extra_FSMBCO_add_new_tags_metabox(){
		$id = 'FSMBCO-post_tag'; // it should be unique
		$heading = __('Categories', 'fsm-backend-category-organizer'); // meta box heading
		$callback = 'FSMBCO_metabox_content'; // the name of the callback function
		$post_type = 'post';
		$position = 'side';
		$pri = 'default'; // priority, 'default' is good for us
		add_meta_box( $id, $heading, array( $this, $callback), $post_type, $position, $pri);
	}
	
	
	//Generate the metabox of categories that substitute the one that WP has by default

	public function FSMBCO_metabox_content($post,$callback_args) {
		
		$tax = $callback_args['args'];

		
		//Hide the full category list (by css)
		$hide_full = isset($this->backend_category_organizer_options['ocultar_full_list'][$tax]);
		$defaults = array( 'taxonomy' => $tax );
		if ( ! isset( $box['args'] ) || ! is_array( $box['args'] ) ) {
			$args = array();
		} else {
			$args = $box['args'];
		}
		$r = wp_parse_args( $args, $defaults );
		$tax_name = esc_attr( $r['taxonomy'] );
		$taxonomy = get_taxonomy( $r['taxonomy'] );

		
		
		
		?>
		<div id="taxonomy-<?php echo $tax_name; ?>" class="categorydiv FSMBCO_categorydiv">

			<div id="FSMBCO_selcats_<?php echo $tax_name; ?>" class="FSMBCO_selcats">
			<?php FSMBCO_selected_terms_checklist( $tax_name,false ); ?>
			</div>
			
			<div class="scrollable_tabs">
			<ul id="ecs_<?php echo $tax_name; ?>-tabs" class="category-tabs fsmbco_tab">


				<?php
				//Draw the menu
				$mainecs_cats = $this->backend_category_organizer_options[$tax];	//categories selected in the options page

				//obtain categories info
				$categories = array();
				foreach($mainecs_cats as $categoria_id) {
					//WPML - obtain equivalent category in the current language
					if (class_exists('SitePress')) {
						$categoria_id = apply_filters( 'wpml_object_id', $categoria_id, $tax, FALSE  );
						if (!$categoria_id) { continue; }
					}
					$categoria = get_term($categoria_id,$tax);
					if (!empty($categoria)) {$categories[] = $categoria;}
				}
				
				//if there are not categories, force show the full list
				if (empty($categories)) { $hide_full=false;}
				?>
				
				<li class="tabs" <?php if ($hide_full) { echo 'style="display:none;"'; } ?>>
					<a href="#<?php echo $tax_name; ?>-all"><?php echo $taxonomy->labels->all_items; ?></a>
				</li>

				<?php 
				//Let's look at which categories have the option enabled to appear in the menu
				$show_next = $hide_full;
				foreach($categories as $categoria) {
				?>
				
				<li class="hide-if-no-js <?php if ($show_next) {echo 'tabs';}?>" id="tabfor-<?php echo $tax_name.'_'.$categoria->term_id; ?>">
					<a href="#<?php echo $tax_name.'_'.$categoria->term_id; ?>"><?php echo $categoria->name; ?></a>
				</li>
				<?php 
					$show_next = false;
				}

				?>

			</ul>
			</div>


			<div id="<?php echo $tax_name; ?>-all" class="tabs-panel all_cats_tab" <?php if ($hide_full) { echo 'style="display: none;"'; } ?>>
				<?php
				$name = ( $tax_name == 'category' ) ? 'post_category' : 'tax_input[' . $tax_name . ']';
				echo "<input type='hidden' name='{$name}[]' value='0' />";
				?>
				<ul id="<?php echo $tax_name; ?>checklist" data-wp-lists="list:<?php echo $tax_name; ?>" class="categorychecklist form-no-clear">
					<?php FSMBCO_terms_checklist( $post->ID, array( 'taxonomy' => $tax_name, 'popular_cats' => array() ) ); ?>
				</ul>
			</div>


		<?php

		//List of checkboxes
		$show_next = $hide_full;

		foreach($categories as $categoria) {
		?>

			<div id="<?php echo $tax_name.'_'.$categoria->term_id; ?>" class="tabs-panel" <?php if (!$show_next) { echo 'style="display: none;"'; } ?>>
				<ul id="<?php echo $tax_name.'_'.$categoria->term_id; ?>checklist" data-wp-lists="list:<?php echo $tax_name; ?>" class="categorychecklist form-no-clear chklistmod">
					<?php 
						FSMBCO_terms_checklist( $post->ID, array(
							'taxonomy' => $tax_name,
							'popular_cats' => array(),
							'descendants_and_self' => $categoria->term_id,
							'xtest' => true,
							'exclude' => $mainecs_cats
							) );
					?>
				</ul>
			</div>


		<?php 
			$show_next = false;
		}
		?>
		</div>
		<?php

	}
	
	
	
	
	
//cal afegir tabs aquí
	public function backend_category_organizer_add_plugin_page() {
		$page = add_options_page(
			__('FSM Backend Category Organizer','fsm-backend-category-organizer'), // page_title
			__('FSM Backend Category Organizer','fsm-backend-category-organizer'), // menu_title
			'manage_options', // capability
			'category-organizer', // menu_slug
			array( $this, 'backend_category_organizer_create_admin_page' ) // function
		);

		add_action('admin_print_scripts-' . $page, array(&$this,'backend_category_organizer_admin_header'));

	}

	public function backend_category_organizer_admin_header() {
		/*
		 * It will be called only on your plugin admin page, enqueue our script here
		 */
		 
		wp_enqueue_script( 'FSMBCO_options', plugin_dir_url(__FILE__) . 'js/FSMBCO_options_page.js', array('jquery','jquery-ui-sortable') );

	}
	
	
	public function output_sections() {

		$numtabs = 0;
		$tabsmenu = '';	
		
		$taxos = get_taxonomies(array('public'   => true),'objects');
		
		foreach ($taxos as $taxonomy)
		{
			if ($taxonomy->hierarchical) 
			{
				$tabsmenu.='<option value="'.$taxonomy->name.'"'. ($taxonomy->name == $this->taxonomy?'selected':'').'>'.$taxonomy->labels->name.'</option>';
				$numtabs++;
			}
		}
		
		if ( $numtabs < 2 ) return;
		
		echo '<div class="manage-menus">
			<form method="get" action="'.admin_url( 'options-general.php').'">
			<input type="hidden" name="page" value="category-organizer"/>
			<label for="select-taxonomy-to-edit" class="selected-taxonomy">'.__('Select a taxonomy to edit:', 'fsm-backend-category-organizer').'</label>
			<select name="section" id="select-taxonomy-to-edit">'.
			$tabsmenu.'</select>
			<span class="submit-btn"><input type="submit" class="button" value="'.__('Select', 'fsm-backend-category-organizer').'"></span>
			</form></div>';
			
			
		
	
	}

	public function backend_category_organizer_create_admin_page() {
?>

		<div class="wrap">
			<h2><?php _e('FSM Backend Category Organizer','fsm-backend-category-organizer'); ?></h2>
			<p><?php _e('FSM Backend Category Organizer allows you to group and sort categories and another taxonomy items to show them more efficiently on the post editing page. This plugin does not alter the categories and taxonomy items in the public area.<br/><br/>You can find more information about this plugin at <a href="https://wp.fesomia.cat/plugins/fsm-backend-category-organizer" target="_blank">https://wp.fesomia.cat/plugins/fsm-backend-category-organizer</a>','fsm-backend-category-organizer'); ?></p>

			<?php
			
			$this->output_sections();
			$formaction = 'options.php?section='.$this->taxonomy;
			
			?>

			<form method="post" action="<?php echo $formaction; ?>">
				<?php
					settings_fields( 'backend_category_organizer_option_group' );
					do_settings_sections( 'category-organizer-admin' );
					submit_button();
				?>
			</form>
		</div>
	<?php
	}
	
	
	
	
	
	public function backend_category_organizer_page_init() {
		 //wp_register_script( 'backend_category_organizer_select', plugins_url('/js/FSMBCO_options_page.js', __FILE__) );


		register_setting(
			'backend_category_organizer_option_group', // option_group
			'backend_category_organizer_config', // option_name
			array( $this, 'backend_category_organizer_sanitize' ) // sanitize_callback
		);

		add_settings_section(
			'backend_category_organizer_setting_section', // id
			__('Settings','fsm-backend-category-organizer'), // title
			array( $this, 'backend_category_organizer_section_info' ), // callback
			'category-organizer-admin' // page
		);

		add_settings_field(
			'activar_plugin', // id
			__('Options','fsm-backend-category-organizer'), // title
			array( $this, 'options_plugin_callback' ), // callback
			'category-organizer-admin', // page
			'backend_category_organizer_setting_section' // section
		);


		add_settings_field(
			$this->taxonomy, // id
			__('Categories','fsm-backend-category-organizer'), // title
			array( $this, 'categories_callback' ), // callback
			'category-organizer-admin', // page
			'backend_category_organizer_setting_section' // section
		);

	}

	public function backend_category_organizer_sanitize($input) {
		$sanitary_values = array();
		
		$global_values = $this->backend_category_organizer_options;
		$current_tax = $this->taxonomy;
		
		//activar plugin
		$sanitary_values['activar_plugin']=isset($global_values['activar_plugin'])?$global_values['activar_plugin']:array();
		
		if (isset($input['activar_plugin'])) {
			$sanitary_values['activar_plugin'][$current_tax] = $input['activar_plugin'][$current_tax];
		}
		else 
		{
			unset($sanitary_values['activar_plugin'][$current_tax]);
		}
		
		//ocultar full list
		$sanitary_values['ocultar_full_list']=isset($global_values['ocultar_full_list'])?$global_values['ocultar_full_list']:array();

		if ( isset( $input['ocultar_full_list'] ) ) {
			$sanitary_values['ocultar_full_list'][$current_tax] = $input['ocultar_full_list'][$current_tax];
		}
		else 
		{
			unset($sanitary_values['ocultar_full_list'][$current_tax]);
		}
		
		
	
		$taxos = get_taxonomies(array('public'   => true),'objects');
		
		foreach ($taxos as $taxonomy)
		{
			if ( isset( $input[$taxonomy->name] ) ) {
				foreach ($input[$taxonomy->name] as $icategoria) {
					$sanitary_values[$taxonomy->name][] = (int)$icategoria;
				}
			}
			else if ( $taxonomy->name != $current_tax && isset ($global_values[$taxonomy->name]) )
			{
				$sanitary_values[$taxonomy->name] = $global_values[$taxonomy->name];
			}
		}

		return $sanitary_values;
	}

	public function backend_category_organizer_section_info() {

	}
	

	
	public function options_plugin_callback() {

		$activa_name = $this->taxonomy;
		printf(
			'<input type="checkbox" name="backend_category_organizer_config[activar_plugin]['.$activa_name.']" id="activar_plugin" value="activar_plugin" %s> <label for="activar_plugin">'.__('Enable for this taxonomy','fsm-backend-category-organizer').' ('.$this->taxonomy.')</label>',
			( isset( $this->backend_category_organizer_options['activar_plugin'][$activa_name] ) && $this->backend_category_organizer_options['activar_plugin'][$activa_name] === 'activar_plugin' ) ? 'checked' : ''
		);
		
		
		echo '<div><em class="infoem">'.__('Uncheck this box to disallow the plugin for this taxonomy. Your settings will remain saved.', 'fsm-backend-category-organizer').'</em></div><br/>';
		printf(
			'<input type="checkbox" name="backend_category_organizer_config[ocultar_full_list]['.$activa_name.']" id="ocultar_full_list" value="ocultar_full_list" %s> <label for="ocultar_full_list">'.__('Hide full list','fsm-backend-category-organizer').'</label>',
			( isset( $this->backend_category_organizer_options['ocultar_full_list'][$activa_name] ) && $this->backend_category_organizer_options['ocultar_full_list'][$activa_name] === 'ocultar_full_list' ) ? 'checked' : ''
		);
		echo '<div><em class="infoem">'.__('By default, at the top, a tab with all taxonomy items is always displayed, in the usual format. This full list tab will remain hidden if you check this box.', 'fsm-backend-category-organizer').'</em></div>';

	}
	


	public function categories_callback() {

		echo '<div id="FSMBCO_catorg_builder">';

		echo '<div class="cat_selector">';

		//If sitepress is enabled, we will show the dropdown in the default language
		if (class_exists('SitePress')) {
			global $sitepress;
			$def_lang = $sitepress->get_default_language();
			$sitepress->switch_lang($def_lang, true);
		}

		wp_dropdown_categories(
		array(
			'hierarchical' => true,
			'orderby' => 'name',
			'class' => 'seleccat',
			'hide_empty' => false,
			'taxonomy'=> $this->taxonomy
			)
		);
		
		
$args = array(
  'orderby' => 'name',
  'order' => 'ASC',
  'parent' => 0,
  'hide_empty' => false
);

$tax = get_terms( $this->taxonomy, $args);
$taxo_array = array();
 

foreach ($tax as $category)
{
	$terms = get_term_children( $category->term_id, $category->taxonomy );
	


	if ( !empty( $terms ) && !is_wp_error( $terms ) ){
		$taxo_array[$category->name] = $category->term_taxonomy_id;
	}
	
}

echo '<script>';

echo "var fsmbco_jsarray = ". json_encode($taxo_array) . ";\n";

echo '</script>';



?>

<script>

var fsmbco_jsarray = <?php echo json_encode($taxo_array); ?>

</script>
<?php

		if (class_exists('SitePress')) {$sitepress->switch_lang(ICL_LANGUAGE_CODE, true); }


		echo '<input type="button" value="'.__('Add','fsm-backend-category-organizer').'" class="seleccat_add button"/>';
		echo '</div>';
		echo '<input type="hidden" id="current_bco_taxonomy" value="'.$this->taxonomy.'">';
		echo '<ul class="cats_list ui-sortable">';

		if (isset( $this->backend_category_organizer_options[$this->taxonomy])) {
			foreach  ($this->backend_category_organizer_options[$this->taxonomy] as $categories) {
				

				$catname = get_term_field( 'name', $categories );
				if ($catname) {
					echo '<li class="ui-state-default" id="acc_'.$categories.'">
						<input type="hidden" name="backend_category_organizer_config['.$this->taxonomy.'][]" value="'.$categories.'"/>'.
						$catname.'<span class="remove"></span></li>';
				}

			}

		}
 
		echo '</ul>';
		echo '&nbsp;<input type="button" value="'.__('Populate','fsm-backend-category-organizer').'" class="seleccat_populate button"/>';
		echo '<em class="infoem" style="padding-left:0;">'.__('Pressing this button replaces the current selection with first level parent categories. Changes are only applied after pressing the Save button.','fsm-backend-category-organizer').'</em>';
		echo '</div>';


	}

}

if ( is_admin() ) {
	$backend_category_organizer = new FSMBCO_CategoryOrganizer(isset($_GET['section'])?$_GET['section']:'');
}


//Operations on activation for compatibility with old versions
function myplugin_activate() {
	//check if and old version of the plugin is installed
	$old_options = get_option('backend_category_organizer_option_name');

	$option_name = 'backend_category_organizer_config';
	$saved_options = get_option( $option_name );
	
	//check if old options exists at all and then activate for the default taxonomy (category) if necessary
	if ($old_options && !$saved_options)
	{
		$saved_options = array();
		if ( isset($old_options['activar_plugin']) )
		{
			$saved_options['activar_plugin']=array('category'=>'activar_plugin');
		}
		if ( isset($old_options['ocultar_full_list']) )
		{
			$saved_options['ocultar_full_list']=array('category'=>'ocultar_full_list');
		}
		
		if ( isset($old_options['categories']) )
		{
			$saved_options['category'] = $old_options['categories'];
		}
		
		update_option( $option_name, $saved_options );
		
		
	}
	
}
register_activation_hook( __FILE__, 'myplugin_activate' );

	